Struct amazon_sp_aplus_content::models::standard_image_text_overlay_module::StandardImageTextOverlayModule
source · [−]pub struct StandardImageTextOverlayModule {
pub overlay_color_type: ColorType,
pub block: Option<Box<StandardImageTextBlock>>,
}Expand description
StandardImageTextOverlayModule : A standard background image with a floating text box.
Fields
overlay_color_type: ColorTypeblock: Option<Box<StandardImageTextBlock>>Implementations
sourceimpl StandardImageTextOverlayModule
impl StandardImageTextOverlayModule
sourcepub fn new(overlay_color_type: ColorType) -> StandardImageTextOverlayModule
pub fn new(overlay_color_type: ColorType) -> StandardImageTextOverlayModule
A standard background image with a floating text box.